==> src-foundations-0.12.0.tgz: package/src/palette/global.ts <==
import { colors } from "../theme"

export const brand = {
	300: colors.blues[5],
	400: colors.blues[6],
	500: colors.blues[7],
	600: colors.blues[8],
	800: colors.blues[9],

	// legacy names: please do not use
	dark: colors.blues[5],
	main: colors.blues[6],
	bright: colors.blues[7],
	pastel: colors.blues[8],
	faded: colors.blues[9],
}
export const brandAlt = {
	300: colors.yellows[0],
	400: colors.yellows[1],

	// legacy names: please do not use
	dark: colors.yellows[0],
	main: colors.yellows[1],
}
// continue to expose legacy name for compatibility
export const brandYellow = brandAlt
export const neutral = {
	7: colors.grays[0],
	20: colors.grays[1],
	46: colors.grays[2],
	60: colors.grays[3],
	86: colors.grays[4],
	93: colors.grays[5],
	97: colors.grays[6],
	100: colors.grays[7],
	specialReport: colors.grays[8],
}
export const error = {
	400: colors.reds[1],
	500: colors.reds[2],

	// legacy names: please do not use
	main: colors.reds[1],
	bright: colors.reds[2],
}
export const success = {
	400: colors.greens[1],

	// legacy names: please do not use
	main: colors.greens[1],
}
export const news = {
	300: colors.reds[0],
	400: colors.reds[1],
	500: colors.reds[2],
	600: colors.reds[3],
	800: colors.reds[4],

	// legacy names: please do not use
	dark: colors.reds[0],
	main: colors.reds[1],
	bright: colors.reds[2],
	pastel: colors.reds[3],
	faded: colors.reds[4],
}
export const opinion = {
	300: colors.oranges[0],
	400: colors.oranges[1],
	500: colors.oranges[2],
	600: colors.oranges[3],
	800: colors.oranges[4],

	// legacy names: please do not use
	dark: colors.oranges[0],
	main: colors.oranges[1],
	bright: colors.oranges[2],
	pastel: colors.oranges[3],
	faded: colors.oranges[4],
}
export const sport = {
	300: colors.blues[0],
	400: colors.blues[1],
	500: colors.blues[2],
	600: colors.blues[3],
	800: colors.blues[4],

	// legacy names: please do not use
	dark: colors.blues[0],
	main: colors.blues[1],
	bright: colors.blues[2],
	pastel: colors.blues[3],
	faded: colors.blues[4],
}
export const culture = {
	300: colors.browns[0],
	400: colors.browns[1],
	500: colors.browns[2],
	600: colors.browns[3],
	800: colors.browns[4],

	// legacy names: please do not use
	dark: colors.browns[0],
	main: colors.browns[1],
	bright: colors.browns[2],
	pastel: colors.browns[3],
	faded: colors.browns[4],
}
export const lifestyle = {
	300: colors.pinks[0],
	400: colors.pinks[1],
	500: colors.pinks[2],
	600: colors.pinks[3],
	800: colors.pinks[4],

	// legacy names: please do not use
	dark: colors.pinks[0],
	main: colors.pinks[1],
	bright: colors.pinks[2],
	pastel: colors.pinks[3],
	faded: colors.pinks[4],
}
export const labs = {
	300: colors.greens[2],
	400: colors.greens[3],

	// legacy names: please do not use
	dark: colors.greens[2],
	main: colors.greens[3],
}

==> src-foundations-0.12.1.tgz: package/src/palette/global.ts <==
import { colors } from "../theme"

export const brand = {
	300: colors.blues[5],
	400: colors.blues[6],
	500: colors.blues[7],
	600: colors.blues[8],
	800: colors.blues[9],

	// legacy names: please do not use
	dark: colors.blues[5],
	main: colors.blues[6],
	bright: colors.blues[7],
	pastel: colors.blues[8],
	faded: colors.blues[9],
}
export const brandAlt = {
	300: colors.yellows[0],
	400: colors.yellows[1],

	// legacy names: please do not use
	dark: colors.yellows[0],
	main: colors.yellows[1],
}
// continue to expose legacy name for compatibility
export const brandYellow = brandAlt
export const neutral = {
	7: colors.grays[0],
	20: colors.grays[1],
	46: colors.grays[2],
	60: colors.grays[3],
	86: colors.grays[4],
	93: colors.grays[5],
	97: colors.grays[6],
	100: colors.grays[7],
	// TODO: move this into background.ts
	specialReport: "#3F464A",
}
export const error = {
	400: colors.reds[1],
	500: colors.reds[2],

	// legacy names: please do not use
	main: colors.reds[1],
	bright: colors.reds[2],
}
export const success = {
	400: colors.greens[1],

	// legacy names: please do not use
	main: colors.greens[1],
}
export const news = {
	300: colors.reds[0],
	400: colors.reds[1],
	500: colors.reds[2],
	600: colors.reds[3],
	800: colors.reds[4],

	// legacy names: please do not use
	dark: colors.reds[0],
	main: colors.reds[1],
	bright: colors.reds[2],
	pastel: colors.reds[3],
	faded: colors.reds[4],
}
export const opinion = {
	300: colors.oranges[0],
	400: colors.oranges[1],
	500: colors.oranges[2],
	600: colors.oranges[3],
	800: colors.oranges[4],

	// legacy names: please do not use
	dark: colors.oranges[0],
	main: colors.oranges[1],
	bright: colors.oranges[2],
	pastel: colors.oranges[3],
	faded: colors.oranges[4],
}
export const sport = {
	300: colors.blues[0],
	400: colors.blues[1],
	500: colors.blues[2],
	600: colors.blues[3],
	800: colors.blues[4],

	// legacy names: please do not use
	dark: colors.blues[0],
	main: colors.blues[1],
	bright: colors.blues[2],
	pastel: colors.blues[3],
	faded: colors.blues[4],
}
export const culture = {
	300: colors.browns[0],
	400: colors.browns[1],
	500: colors.browns[2],
	600: colors.browns[3],
	800: colors.browns[4],

	// legacy names: please do not use
	dark: colors.browns[0],
	main: colors.browns[1],
	bright: colors.browns[2],
	pastel: colors.browns[3],
	faded: colors.browns[4],
}
export const lifestyle = {
	300: colors.pinks[0],
	400: colors.pinks[1],
	500: colors.pinks[2],
	600: colors.pinks[3],
	800: colors.pinks[4],

	// legacy names: please do not use
	dark: colors.pinks[0],
	main: colors.pinks[1],
	bright: colors.pinks[2],
	pastel: colors.pinks[3],
	faded: colors.pinks[4],
}
export const labs = {
	300: colors.greens[2],
	400: colors.greens[3],

	// legacy names: please do not use
	dark: colors.greens[2],
	main: colors.greens[3],
}
